from distutils.core import setup
from setuptools import find_packages

setup(
    name='LIBRARYNAME',
    version=None,
    packages=find_packages(),
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.rst').read(),
    author=None,
    author_email=None,
    keywords='workflow tool',
    url=None
)