
from uperations.library import Library

class LIBRARYNAME(Library):

    @staticmethod
    def name():
        return "LIBRARYNAME"

    @staticmethod
    def description():
        return "Not description provided"

    def operations(self):
        return {
        }